@@ -88,9 +88,11 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("ordx", "ordy"))
 #'          \itemize{
 #'          \item Use \code{"bw"} for a white background with gray grids
 #'          \item \code{"classic"} for a classic theme (black border, no grids)
-#'          \item \code{"minimal"} for a minimalistic theme (no border,gray grids) or 
-#'          \item \code{"none"} for no borders, grids and ticks.
+#'          \item \code{"minimal"} for a minimalistic theme (no border,gray grids)
+#'          \item \code{"none"} for no borders, grids and ticks or
+#'          \item \code{"themr"} if you are using the \code{ggthemr} package
 #'          }
+#'          See \url{http://rpubs.com/sjPlot/custplot} for details and examples.
 #' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
 #'          want to plot any graphs. In either case, the ggplot-object will be returned as value.
 #' @return (Insisibily) returns the ggplot-object with the complete plot (\code{plot}) as well as the data frame that
@@ -337,6 +339,9 @@ sjp.corr <- function(data,
   if (is.null(theme)) {
     ggtheme <- theme_gray()
   }
+  else if (theme=="themr") {
+    ggtheme <- NULL
+  }
   else if (theme=="bw") {
     ggtheme <- theme_bw()
   }
@@ -366,7 +371,7 @@ sjp.corr <- function(data,
   # --------------------------------------------------------
   # Set up visibility oftick marks
   # --------------------------------------------------------
-  if (!showTickMarks) {
+  if (!showTickMarks && !is.null(ggtheme)) {
     ggtheme <- ggtheme + theme(axis.ticks = element_blank())
   }
   if (!showCorrelationValueLabels) {
@@ -434,13 +439,17 @@ sjp.corr <- function(data,
   }
   corrPlot <- corrPlot +
     geom_text(label=sprintf("%s%s", correlationValueLabels, correlationPValues), colour=valueLabelColor, alpha=valueLabelAlpha, size=valueLabelSize) +
-    labs(title=title, x=NULL, y=NULL, fill=legendTitle) +
-    ggtheme +
-    # set font size for axes.
-    theme(axis.text = element_text(size=rel(axisLabelSize), colour=axisLabelColor), 
-          axis.text.x = element_text(angle=axisLabelAngle.x),
-          axis.text.y = element_text(angle=axisLabelAngle.y),
-          plot.title = element_text(size=rel(titleSize), colour=titleColor))
+    labs(title=title, x=NULL, y=NULL, fill=legendTitle)
+  # apply theme
+  if (!is.null(ggtheme)) {
+    corrPlot <- corrPlot +
+      ggtheme +
+      # set font size for axes.
+      theme(axis.text = element_text(size=rel(axisLabelSize), colour=axisLabelColor), 
+            axis.text.x = element_text(angle=axisLabelAngle.x),
+            axis.text.y = element_text(angle=axisLabelAngle.y),
+            plot.title = element_text(size=rel(titleSize), colour=titleColor))
+  }
   # the panel-border-property can only be applied to the bw-theme
   if (!is.null(borderColor)) {
     if (!is.null(theme) && theme=="bw") {
