@@ -17,7 +17,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("vars", "Beta", "xv", "lo
 #'          \code{\link{sjp.reglin}} \cr
 #'          \code{\link{sjp.lm.int}} \cr
 #'          \code{\link{sjp.scatter}} \cr
-#'          \code{\link{sju.betaCoef}}
+#'          \code{\link{sjs.betaCoef}}
 #' 
 #' @note Based on an an idea from surefoss:
 #' \url{http://www.surefoss.org/dataanalysis/plotting-odds-ratios-aka-a-forrestplot-with-ggplot2/}
@@ -89,9 +89,11 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("vars", "Beta", "xv", "lo
 #'          \itemize{
 #'          \item Use \code{"bw"} for a white background with gray grids
 #'          \item \code{"classic"} for a classic theme (black border, no grids)
-#'          \item \code{"minimal"} for a minimalistic theme (no border,gray grids) or 
-#'          \item \code{"none"} for no borders, grids and ticks.
+#'          \item \code{"minimal"} for a minimalistic theme (no border,gray grids)
+#'          \item \code{"none"} for no borders, grids and ticks or
+#'          \item \code{"themr"} if you are using the \code{ggthemr} package (in such cases, you may use the \code{ggthemr::swatch} function to retrieve theme-colors for the \code{pointColor} parameter)
 #'          }
+#'          See \url{http://rpubs.com/sjPlot/custplot} for details and examples.
 #' @param flipCoordinates If \code{TRUE} (default), predictors are plotted on the left y-axis and estimate
 #'          values are plotted on the x-axis.
 #' @param majorGridColor Specifies the color of the major grid lines of the diagram background.
@@ -220,7 +222,7 @@ sjp.lm <- function(fit,
   # retrieve betas, leave out intercept ([-1])
   bv <- coef(fit)[-1]
   # retrieve standardized betas
-  stdbv <- sju.betaCoef(fit)
+  stdbv <- sjs.betaCoef(fit)
   # init data column for p-values
   ps <- sprintf("%.*f", labelDigits, bv)
   pstdbv <- sprintf("%.*f", labelDigits, stdbv)
@@ -277,7 +279,7 @@ sjp.lm <- function(fit,
   # case no values are drawn, we simply use an empty string.
   # finally, we need the p-values of the coefficients, because the value
   # labels may have different colours according to their significance level
-  betas <- cbind(tmp, c(ps), sju.betaCoef(fit), c(pstdbv), pv)
+  betas <- cbind(tmp, c(ps), sjs.betaCoef(fit), c(pstdbv), pv)
   # --------------------------------------------------------
   # check if user defined labels have been supplied
   # if not, use variable names from data frame
@@ -340,6 +342,9 @@ sjp.lm <- function(fit,
     ggtheme <- theme_gray()
     hideGridColor <- c("gray90")
   }
+  else if (theme=="themr") {
+    ggtheme <- NULL
+  }
   else if (theme=="bw") {
     ggtheme <- theme_bw()
   }
@@ -370,7 +375,7 @@ sjp.lm <- function(fit,
   # --------------------------------------------------------
   # Set up visibility of tick marks
   # --------------------------------------------------------
-  if (!showTickMarks) {
+  if (!showTickMarks && !is.null(ggtheme)) {
     ggtheme <- ggtheme + theme(axis.ticks = element_blank())
   }
   if (!showAxisLabels.y) {
@@ -410,14 +415,20 @@ sjp.lm <- function(fit,
     scale_y_continuous(limits=c(lower_lim,upper_lim), breaks=ticks, labels=ticks) +
     # set value labels to x-axis
     scale_x_discrete(labels=axisLabels.y, limits=c(1:nrow(betas))) +
-    labs(title=title, x=NULL, y=axisTitle.x) +
-    ggtheme +
-    # set axes text and 
-    theme(axis.text = element_text(size=rel(axisLabelSize), colour=axisLabelColor), 
-          axis.title = element_text(size=rel(axisTitleSize), colour=axisTitleColor), 
-          axis.text.x = element_text(angle=axisLabelAngle.x),
-          axis.text.y = element_text(angle=axisLabelAngle.y),
-          plot.title = element_text(size=rel(titleSize), colour=titleColor))
+    labs(title=title, x=NULL, y=axisTitle.x)
+  # --------------------------------------------------------
+  # apply theme
+  # --------------------------------------------------------
+  if (!is.null(ggtheme)) {
+    betaplot <- betaplot +
+      ggtheme +
+      # set axes text and 
+      theme(axis.text = element_text(size=rel(axisLabelSize), colour=axisLabelColor), 
+            axis.title = element_text(size=rel(axisTitleSize), colour=axisTitleColor), 
+            axis.text.x = element_text(angle=axisLabelAngle.x),
+            axis.text.y = element_text(angle=axisLabelAngle.y),
+            plot.title = element_text(size=rel(titleSize), colour=titleColor))
+  }
   # --------------------------------------------------------
   # flip coordinates?
   # --------------------------------------------------------
@@ -669,14 +680,20 @@ sjp.reglin <- function(fit,
 #' @return an updated fitted linear model where outliers are dropped out.
 #' 
 #' @examples
+#' \dontrun{
 #' # fit linear model
 #' fit <- lm(airquality$Ozone ~ airquality$Wind + airquality$Temp + airquality$Solar.R)
-#' fit.updated <- sjp.lm.ma(fit)
+#' fit.updated <- sjp.lm.ma(fit)}
 #' 
-#' @importFrom lmtest bptest
 #' @importFrom car outlierTest crPlots durbinWatsonTest leveragePlots ncvTest spreadLevelPlot
 #' @export
 sjp.lm.ma <- function(linreg, showOriginalModelOnly=TRUE, completeDiagnostic=FALSE) {
+  # ------------------------
+  # check if suggested package is available
+  # ------------------------
+  if (!requireNamespace("lmtest", quietly = TRUE)) {
+    stop("Package 'lmtest' needed for this function to work. Please install it.", call. = FALSE)
+  }
   # ---------------------------------
   # remove outliers
   # ---------------------------------
@@ -823,7 +840,7 @@ sjp.lm.ma <- function(linreg, showOriginalModelOnly=TRUE, completeDiagnostic=FAL
     # Non-constant residuals
     # ---------------------------------
     print(ncvTest(linreg))
-    print(bptest(linreg))
+    print(lmtest::bptest(linreg))
     print(spreadLevelPlot(linreg))
   }
   # return updated model
@@ -909,9 +926,11 @@ sjp.lm.ma <- function(linreg, showOriginalModelOnly=TRUE, completeDiagnostic=FAL
 #'          \itemize{
 #'          \item Use \code{"bw"} for a white background with gray grids
 #'          \item \code{"classic"} for a classic theme (black border, no grids)
-#'          \item \code{"minimal"} for a minimalistic theme (no border,gray grids) or 
-#'          \item \code{"none"} for no borders, grids and ticks.
+#'          \item \code{"minimal"} for a minimalistic theme (no border,gray grids)
+#'          \item \code{"none"} for no borders, grids and ticks or
+#'          \item \code{"themr"} if you are using the \code{ggthemr} package
 #'          }
+#'          See \url{http://rpubs.com/sjPlot/custplot} for details and examples.
 #' @param majorGridColor Specifies the color of the major grid lines of the diagram background.
 #' @param minorGridColor Specifies the color of the minor grid lines of the diagram background.
 #' @param hideGrid.x If \code{TRUE}, the x-axis-gridlines are hidden. Default if \code{FALSE}.
@@ -1050,6 +1069,9 @@ sjp.lm1 <- function(fit,
     ggtheme <- theme_gray()
     hideGridColor <- c("gray90")
   }
+  else if (theme=="themr") {
+    ggtheme <- NULL
+  }
   else if (theme=="bw") {
     ggtheme <- theme_bw()
   }
@@ -1080,7 +1102,7 @@ sjp.lm1 <- function(fit,
   # --------------------------------------------------------
   # Set up visibility of tick marks
   # --------------------------------------------------------
-  if (!showTickMarks) {
+  if (!showTickMarks && !is.null(ggtheme)) {
     ggtheme <- ggtheme + theme(axis.ticks = element_blank())
   }
   # -----------------------------------------------------------
@@ -1125,12 +1147,18 @@ sjp.lm1 <- function(fit,
   reglinplot <- reglinplot + 
     labs(title=title,
          x=axisLabel.x,
-         y=axisLabel.y) + 
-    ggtheme +
-    # set axes text and title
-    theme(axis.text = element_text(size=rel(axisLabelSize), colour=axisLabelColor), 
-          axis.title = element_text(size=rel(axisTitleSize), colour=axisTitleColor), 
-          plot.title = element_text(size=rel(titleSize), colour=titleColor))
+         y=axisLabel.y)
+  # --------------------------------------------------------
+  # apply theme
+  # --------------------------------------------------------
+  if (!is.null(ggtheme)) {
+    reglinplot <- reglinplot + 
+      ggtheme +
+      # set axes text and title
+      theme(axis.text = element_text(size=rel(axisLabelSize), colour=axisLabelColor), 
+            axis.title = element_text(size=rel(axisTitleSize), colour=axisTitleColor), 
+            plot.title = element_text(size=rel(titleSize), colour=titleColor))
+  }
   # -----------------------------------------------------------
   # prepare border and grid colors
   # -----------------------------------------------------------
