@@ -17,6 +17,8 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("Row", "Column", "p.value
 #' @param titleSize The size of the plot title. Default is 1.3.
 #' @param titleColor The color of the plot title. Default is \code{"black"}.
 #' @param axisLabels Labels for the x- andy y-axis
+#'          axisLabels are detected automatically if each variable has
+#'          a \code{"variable.label"} attribute (see \code{\link{sji.setVariableLabels}}) for details).
 #' @param valueLabelColor the color of the value labels (numbers) inside the diagram
 #' @param valueLabelSize The size of value labels in the diagram. Default is 4.5, recommended values range
 #'          between 2 and 8
@@ -80,6 +82,26 @@ sjp.chi2 <- function(df,
                      hideLegend=TRUE,
                      legendTitle=NULL,
                      printPlot=TRUE) {
+  # --------------------------------------------------------
+  # try to automatically set labels is not passed as parameter
+  # --------------------------------------------------------
+  if (is.null(axisLabels)) {
+    axisLabels <- c()
+    # if yes, iterate each variable
+    for (i in 1:ncol(df)) {
+      # retrieve variable name attribute
+      vn <- autoSetVariableLabels(df[,i])
+      # if variable has attribute, add to variableLabel list
+      if (!is.null(vn)) {
+        axisLabels <- c(axisLabels, vn)
+      }
+      else {
+        # else break out of loop
+        axisLabels <- NULL
+        break
+      }
+    }
+  }
   # ----------------------------------------------------------------
   # Calculation of Chi2-matrix taken from following blog-posting:
   # http://talesofr.wordpress.com/2013/05/05/ridiculously-photogenic-factors-heatmap-with-p-values/
@@ -97,8 +119,6 @@ sjp.chi2 <- function(df,
                       "p.value" = round(test$p.value, 4))
     return(out)
   })
-  
-  
   # ----------------------------
   # check if user defined labels have been supplied
   # if not, use variable names from data frame
@@ -109,15 +129,6 @@ sjp.chi2 <- function(df,
   # --------------------------------------------------------
   # unlist labels
   # --------------------------------------------------------
-  # Help function that unlists a list into a vector
-  unlistlabels <- function(lab) {
-    dummy <- unlist(lab)
-    labels <- c()
-    for (i in 1:length(dummy)) {
-      labels <- c(labels, as.character(dummy[i]))
-    }
-    return (labels)
-  }
   if (!is.null(axisLabels) && is.list(axisLabels)) {
     axisLabels <- unlistlabels(axisLabels)
   }
