@@ -95,9 +95,11 @@
 #'          \itemize{
 #'          \item Use \code{"bw"} for a white background with gray grids
 #'          \item \code{"classic"} for a classic theme (black border, no grids)
-#'          \item \code{"minimal"} for a minimalistic theme (no border,gray grids) or 
-#'          \item \code{"none"} for no borders, grids and ticks.
+#'          \item \code{"minimal"} for a minimalistic theme (no border,gray grids)
+#'          \item \code{"none"} for no borders, grids and ticks or
+#'          \item \code{"themr"} if you are using the \code{ggthemr} package (in such cases, you may use the \code{ggthemr::swatch} function to retrieve theme-colors for the \code{pointColors} parameter)
 #'          }
+#'          See \url{http://rpubs.com/sjPlot/custplot} for details and examples.
 #' @param useFacetGrid \code{TRUE} when each scatter plot group should be plotted as single facet instead of 
 #'          an integrated single graph. Only applies if \code{grp} is not \code{NULL}. Each category of
 #'          \code{grp} will be plotted in an own facet.
@@ -290,6 +292,9 @@ sjp.scatter <- function(x,
     ggtheme <- theme_gray()
     hideGridColor <- c("gray90")
   }
+  else if (theme=="themr") {
+    ggtheme <- NULL
+  }
   else if (theme=="bw") {
     ggtheme <- theme_bw()
   }
@@ -308,7 +313,7 @@ sjp.scatter <- function(x,
   # --------------------------------------------------------
   # Hide or show Tick Marks and Category Labels (x axis text) 
   # --------------------------------------------------------
-  if (!showTickMarks) {
+  if (!showTickMarks && !is.null(ggtheme)) {
     ggtheme <- ggtheme + theme(axis.ticks = element_blank())
   }
   # --------------------------------------------------------
@@ -373,10 +378,18 @@ sjp.scatter <- function(x,
   # set font size for axes.
   # --------------------------------------------------------
   scatter <- scatter + 
-    labs(title=title, x=axisTitle.x, y=axisTitle.y, colour=legendTitle) +
-    theme(axis.text = element_text(size=rel(axisTickMarkSize), colour=axisTickMarkColor), 
-          axis.title = element_text(size=rel(axisTitleSize), colour=axisTitleColor), 
-          plot.title = element_text(size=rel(titleSize), colour=titleColor))
+    labs(title=title, x=axisTitle.x, y=axisTitle.y, colour=legendTitle)
+  # --------------------------------------------------------
+  # apply theme
+  # --------------------------------------------------------
+  if (!is.null(ggtheme)) {
+    scatter <- scatter + 
+      ggtheme +
+      # do minor modifications to theme
+      theme(axis.text = element_text(size=rel(axisTickMarkSize), colour=axisTickMarkColor), 
+            axis.title = element_text(size=rel(axisTitleSize), colour=axisTitleColor), 
+            plot.title = element_text(size=rel(titleSize), colour=titleColor))
+  }
   # --------------------------------------------------------
   # Hide or show tick marks
   # --------------------------------------------------------
